@@ -5,11 +5,11 @@
 from .api_key_manager import APIKeyManager
 from .api_key_manager import APIKey
 from .decorators import api_key_required
+from .utils import get_ext_config
 from .utils import current_api_key
 
 
-__build__ = 238
-__version__ = '0.1.7'
+__version__ = '0.2.1'
 __author__ = '@jthop'
 __copyright__ = f'Copyright 2022 {__author__}'
 
